@@ -149,7 +149,7 @@ int xrecv(conn_list_t *cl, void *packet)
 */
 void add_queue(packet_queue_t **q, void *packet, size_t s)
 {
-  queue_element_t *e;
+  queue_element_t *e, *p;
 
   if(debug_lvl > 3)
     syslog(LOG_DEBUG, "packet to queue: %d", s);
@@ -160,16 +160,17 @@ void add_queue(packet_queue_t **q, void *packet, size_t s)
   if(!*q)
     {
       *q = xmalloc(sizeof(packet_queue_t));
-      (*q)->tail = (*q)->head = NULL;
+      (*q)->head = (*q)->tail = NULL;
     }
 
-  e->prev = (*q)->tail;
   e->next = NULL;
-  if((*q)->tail)
+
+  if((*q)->tail != NULL)
     (*q)->tail->next = e;
 
   (*q)->tail = e;
-  if(!(*q)->head)
+
+  if((*q)->head == NULL)
     (*q)->head = e;
 }
 
