@@ -141,6 +141,12 @@ parse_options(int argc, char **argv, char **envp)
     }
 }
 
+void memory_full(void)
+{
+  syslog(LOG_ERR, "Memory exhausted; exiting.");
+  exit(1);
+}
+
 /*
   Detach from current terminal, write pidfile, kill parent
 */
@@ -189,6 +195,8 @@ int detach(void)
   else
     syslog(LOG_NOTICE, "tincd %s starting, debug level %d.", VERSION, debug_lvl);
 
+  xalloc_fail_func = memory_full;
+
   return 0;
 }
 
@@ -420,9 +428,24 @@ sigusr2_handler(int a)
   regenerate_keys();
 }
 
+RETSIGTYPE
+sighuh(int a)
+{
+  if(cp_file)
+    syslog(LOG_NOTICE, "Got unexpected signal after %s line %d.",
+	   cp_file, cp_line);
+  else
+    syslog(LOG_NOTICE, "Got unexpected signal.");
+}
+
 void
 setup_signals(void)
 {
+  int i;
+
+  for(i=0;i<32;i++)
+    signal(i,sighuh);
+
   if(signal(SIGTERM, SIG_IGN) != SIG_ERR)
     signal(SIGTERM, sigterm_handler);
   if(signal(SIGQUIT, SIG_IGN) != SIG_ERR)
